@@ -5,7 +5,7 @@
 #
 # Copyright (c) 2008-2009 Yu Yuwei <acevery@gmail.com>
 # Copyright (c) 2009-2014 Caius "kaio" CHANCE <me@kaio.net>
-# Copyright (c) 2012-2015 Mike FABIAN <mfabian@redhat.com>
+# Copyright (c) 2012-2015, 2021-2022 Mike FABIAN <mfabian@redhat.com>
 #
 # This library is free software; you can redistribute it and/or
 # modify it under the terms of the GNU Lesser General Public
@@ -17,10 +17,8 @@
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 # Lesser General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public
-# License along with this library; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
-#
+# You should have received a copy of the GNU Lesser General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>
 
 from typing import Dict
 from typing import Optional
@@ -40,9 +38,9 @@ LOGGER = logging.getLogger('ibus-table')
 
 DEBUG_LEVEL = int(0)
 
-class EngineFactory(IBus.Factory):
+class EngineFactory(IBus.Factory): # type: ignore
     """Table IM Engine Factory"""
-    def __init__(self, bus, db='') -> None:
+    def __init__(self, bus: IBus.Bus, db: str = '') -> None:
         global DEBUG_LEVEL
         try:
             DEBUG_LEVEL = int(str(os.getenv('IBUS_TABLE_DEBUG_LEVEL')))
@@ -62,12 +60,12 @@ class EngineFactory(IBus.Factory):
 
         # init factory
         self.bus = bus
-        super(EngineFactory, self).__init__(connection=bus.get_connection(),
-                                            object_path=IBus.PATH_FACTORY)
+        super().__init__(connection=bus.get_connection(),
+                         object_path=IBus.PATH_FACTORY)
         self.engine_id = 0
         self.engine_path = ''
 
-    def do_create_engine(self, engine_name) -> table.TabEngine:
+    def do_create_engine(self, engine_name: str) -> table.TabEngine:
         if DEBUG_LEVEL > 1:
             LOGGER.debug(
                 'EngineFactory.do_create_engine(engine_name=%s)\n',
@@ -112,4 +110,4 @@ class EngineFactory(IBus.Factory):
         for _db in self.dbdict:
             self.dbdict[_db].sync_usrdb()
         ##print "Have synced user db\n"
-        super(EngineFactory, self).destroy()
+        super().destroy()
